# encoding: UTF-8
#
# Author:    Stefano Harding <riddopic@gmail.com>
# License:   Apache License, Version 2.0
# Copyright: (C) 2014-2015 Stefano Harding
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

require 'securerandom'

module Delphix
  module Utils
    # Return the date and time in "HTTP-date" format as defined by RFC 7231.
    #
    # @return [Date,Time] in "HTTP-date" format
    def utc_httpdate
      Time.now.utc.httpdate
    end

    # Generates a uniq UUID, this is then used to identify this session.
    #
    # @return [String]
    #   Memoize a uniq UUID used to identify this session.
    #
    def request_id
      @uuid ||= SecureRandom.uuid
    end
  end
end
